16.2. cdist-type__debian_backports(7) — cdist 6.9.8 documentation

# 16.2. cdist-type__debian_backports(7)

## 16.2.1. NAME

cdist-type__apt_backports - Install backports

## 16.2.2. DESCRIPTION

This singleton type installs backports for the current OS release. It aborts if backports are not supported for the specified OS or no version codename could be fetched (like Debian unstable).

The package index will be automatically updated if required.

It supports backports from following OSes:

- Debian

- Devuan

- Ubuntu

## 16.2.3. REQUIRED PARAMETERS

None.

## 16.2.4. OPTIONAL PARAMETERS

state

  Represents the state of the backports repository. `present` or `absent`, defaults to `present`.

  Will be directly passed to cdist-type__apt_source(7).

mirror

  The mirror to fetch the backports from. Will defaults to the generic mirror of the current OS.

  Will be directly passed to cdist-type__apt_source(7).

## 16.2.5. BOOLEAN PARAMETERS

None.

## 16.2.6. MESSAGES

None.

## 16.2.7. EXAMPLES

    # setup the backports
    __apt_backports
    __apt_backports --state absent
    __apt_backports --state present --mirror "http://ftp.de.debian.org/debian/"

    # install a backports package
    # currently for the buster release backports
    require="__apt_backports" __package_apt wireguard \
         --target-release buster-backports

## 16.2.8. ABORTS

Aborts if the detected os is not Debian.

Aborts if no distribuition codename could be detected. This is common for the unstable distribution, but there is no backports repository for it already.

## 16.2.9. CAVEATS

For Ubuntu, it setup all componenents for the backports repository: `main`, `restricted`, `universe` and `multiverse`. The user may not want to install proprietary packages, which will only be installed if the user explicitly uses the backports target-release. The user may change this behavior to install backports packages without the need of explicitly select it.

## 16.2.10. SEE ALSO

Official Debian Backports site

cdist-type__apt_source(7)

## 16.2.11. AUTHORS

Matthias Stecher <matthiasstecher at gmx.de>

## 16.2.12. COPYING

Copyright (C) 2020 Matthias Stecher. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.